#!/usr/bin/env python3

from __future__ import division
from __future__ import print_function

import inrelief

SCREENW = 640
SCREENH = 512
CENTERX = SCREENW // 2
CENTERY = SCREENH // 2

DARK = (20, 12, 28)
GRAPHITE = (78, 74, 78)
GRAY = (117, 113, 97)
MAUVE = (68, 36, 52)
BROWN = (133, 76, 48)
RED = (208, 70, 72)
ORANGE = (210, 125, 44)
YELLOW = (218, 212, 94)
LIME = (109, 170, 44)
GREEN = (52, 101, 36)
NAVY = (48, 52, 109)
BLUE = (89, 125, 206)
CYAN = (109, 194, 202)
STEEL = (133, 149, 161)
OCHRE = (210, 170, 153)
LIGHT = (222, 238, 214)

FIERY = (DARK, RED, ORANGE, YELLOW)
ELECTRIC = (DARK, BLUE, CYAN, LIGHT)
METAL = (DARK, GRAPHITE, GRAY, STEEL)
PLASMA = (DARK, GREEN, LIME, LIGHT)
SUNSET = (DARK, MAUVE, BROWN, RED)
EMBERS = (DARK, BROWN, RED, OCHRE)

jetpix = (
	(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0),
	(0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0),
	(0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0),
	(0, 0, 0, 0, 0, 1, 1, 2, 2, 1, 1, 0, 0, 0, 0, 0),
	(0, 0, 0, 1, 1, 2, 2, 3, 3, 2, 2, 1, 1, 0, 0, 0),
	(0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0),
	(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0),
	(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0))

dronepix = (
	(0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0),
	(0, 0, 0, 0, 0, 0, 2, 0, 0, 2, 0, 0, 0, 0, 0, 0),
	(0, 0, 0, 1, 2, 3, 3, 3, 3, 3, 3, 2, 1, 0, 0, 0),
	(0, 0, 0, 1, 2, 3, 1, 3, 3, 1, 3, 2, 1, 0, 0, 0),
	(0, 0, 0, 1, 2, 3, 3, 3, 3, 3, 3, 2, 1, 0, 0, 0),
	(0, 0, 0, 0, 0, 0, 2, 0, 0, 2, 0, 0, 0, 0, 0, 0),
	(0, 0, 0, 0, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 0, 0),
	(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0))

hoverpix = (
	(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0),
	(0, 0, 0, 0, 0, 0, 3, 0, 0, 3, 0, 0, 0, 0, 0, 0),
	(0, 0, 0, 0, 0, 0, 2, 0, 0, 2, 0, 0, 0, 0, 0, 0),
	(0, 0, 0, 0, 0, 0, 0, 1, 1, 0, 0, 0, 0, 0, 0, 0),
	(0, 0, 0, 0, 1, 1, 1, 2, 2, 1, 1, 1, 0, 0, 0, 0),
	(0, 0, 0, 2, 2, 2, 3, 3, 3, 3, 2, 2, 2, 0, 0, 0),
	(0, 0, 0, 0, 1, 1, 1, 2, 2, 1, 1, 1, 0, 0, 0, 0),
	(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0))

buildingpix = (
	(0, 0, 0, 1, 2, 2, 3, 3, 3, 3, 2, 2, 1, 0, 0, 0),
	(0, 0, 0, 1, 2, 0, 3, 0, 0, 3, 0, 2, 1, 0, 0, 0),
	(0, 0, 0, 1, 2, 2, 3, 3, 3, 3, 2, 2, 1, 0, 0, 0),
	(0, 0, 0, 1, 2, 0, 3, 0, 0, 3, 0, 2, 1, 0, 0, 0),
	(0, 0, 0, 1, 2, 2, 3, 3, 3, 3, 2, 2, 1, 0, 0, 0),
	(0, 0, 0, 1, 2, 0, 3, 0, 0, 3, 0, 2, 1, 0, 0, 0),
	(0, 0, 0, 1, 2, 2, 3, 3, 3, 3, 2, 2, 1, 0, 0, 0),
	(0, 0, 0, 1, 2, 0, 3, 0, 0, 3, 0, 2, 1, 0, 0, 0),
	(0, 0, 0, 1, 2, 2, 3, 3, 3, 3, 2, 2, 1, 0, 0, 0),
	(0, 0, 0, 1, 2, 0, 3, 0, 0, 3, 0, 2, 1, 0, 0, 0),
	(0, 0, 0, 1, 2, 2, 3, 3, 3, 3, 2, 2, 1, 0, 0, 0),
	(0, 0, 0, 1, 2, 0, 3, 0, 0, 3, 0, 2, 1, 0, 0, 0),
	(0, 0, 0, 1, 2, 2, 3, 3, 3, 3, 2, 2, 1, 0, 0, 0),
	(0, 0, 0, 1, 2, 0, 3, 0, 0, 3, 0, 2, 1, 0, 0, 0),
	(0, 0, 0, 1, 2, 2, 3, 3, 3, 3, 2, 2, 1, 0, 0, 0),
	(0, 0, 0, 1, 2, 0, 3, 0, 0, 3, 0, 2, 1, 0, 0, 0))

plasmapix = (
	(0, 0, 0, 0, 0, 0, 0, 0),
	(0, 0, 1, 0, 0, 1, 0, 0),
	(0, 1, 0, 0, 0, 0, 1, 0),
	(0, 0, 0, 2, 2, 0, 0, 0),
	(0, 0, 0, 2, 2, 0, 0, 0),
	(0, 1, 0, 0, 0, 0, 1, 0),
	(0, 0, 1, 0, 0, 1, 0, 0),
	(0, 0, 0, 0, 0, 0, 0, 0))

jet = inrelief.Sprite(jetpix, METAL)
jet.set_hotspot(8, 4, -2)
drone = inrelief.Sprite(dronepix, METAL)
drone.set_hotspot(8, 4, -2)
hovertank = inrelief.Sprite(hoverpix, METAL)
hovertank.set_hotspot(8, 4, -2)

building = inrelief.Sprite(buildingpix, SUNSET)
building.set_hotspot(8, 16, -2)

plasma = inrelief.Sprite(plasmapix, PLASMA)
plasma.set_hotspot(4, 4, -2)

stuff = inrelief.DisplayList()
stuff.append(jet, -10, -8, 30)
stuff.append(drone, 12, -5, 50)
stuff.append(hovertank, -12, 5, 80)

for i in (40, 100, 160):
	stuff.append(building, -25, 3, i)
	stuff.append(building, 20, 3, i)
for i in range(20, 220, 40):
	stuff.append(plasma, -6, 8, i)
	stuff.append(plasma, 6, 8, i)

camera = inrelief.Camera(0, 0, 0, SCREENH)

def tuple2rgb(color):
	return "rgb(%d, %d, %d)" % color

rect = '<rect x="{0}" y="{1}" width="{2}" height="{3}" fill="{4}" />'
def renderer(x, y, size, color):
	print(rect.format(x, y, size, size, tuple2rgb(color)))
	pass

header = '<svg width="{0}" height="{1}" viewBox="{2} {3} {0} {1}">'
print(header.format(SCREENW, SCREENH, -CENTERX, -CENTERY))

print(rect.format(-CENTERX, -CENTERY, SCREENW, CENTERX, tuple2rgb(NAVY)))
print(rect.format(-CENTERX, 0, SCREENW, CENTERX, tuple2rgb(DARK)))
print('<circle cx="-3" cy="3" r="30" stroke="none" fill="{0}" />'.format(tuple2rgb(YELLOW)))

stuff.zsort()
stuff.render_through(camera, renderer)

print('</svg>')
